import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom,
  format
} from 'd3';
const svg = select('svg');
const height = +svg.attr('height');
const width = +svg.attr('width');
const margin = {left:80,right:10,top:20,bottom:30};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top -margin.bottom;

const render = data => {
	const xValue = d => d.population;  
  const yValue = d => d.country;

  const xScale = scaleLinear()
  	.domain([0,max(data, xValue)])
  	.range([0,innerWidth]);
  
  const yScale = scaleBand()
  	.domain(data.map(yValue))
  	.range([0,innerHeight])
  	.padding(0.15);

  const g = svg.append('g')
  	.attr('transform',`translate(${margin.left},${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.tickFormat(format('s'))
  const yAxisG = g.append('g').call(axisLeft(yScale));
  yAxisG.selectAll('.domain, .tick line').remove();
  
  const xAxisG = g.append('g').call(xAxis).attr('transform',`translate(0,${innerHeight})`);
  xAxisG.select('.domain').remove();

  
	g.selectAll('rect').data(data)
  	.enter().append('rect')
  		.attr('y', d => yScale(yValue(d)))
  		.attr('height',yScale.bandwidth())
  		.attr('width', d => xScale(xValue(d)))
}

csv('data.csv').then(data => {
  data.forEach(item => {
  	item.population = +item.population * 1000;
  })
	render(data);
})
